<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
	<xsl:output method="html" encoding="EUC-JP" omit-xml-declaration="yes" />
	
	<!-- 一覧用・要約表示 -->
	<xsl:template match="/entrylist">
	
		<!-- カテゴリ切替メニュー -->
		<xsl:for-each select="group[@key='category']">
			<div class="categorymenu">
				<a href="reviewlist.php">
					全て
				</a>
				<a href="reviewcatlist.php?category=book">
					<xsl:if test="@value='book'"><xsl:attribute name="class">selected</xsl:attribute></xsl:if>
					本
				</a>
				<a href="reviewcatlist.php?category=cdvideo">
					<xsl:if test="@value='cdvideo'"><xsl:attribute name="class">selected</xsl:attribute></xsl:if>
					CD・Video
				</a>
				<a href="reviewcatlist.php?category=other">
					<xsl:if test="@value='other'"><xsl:attribute name="class">selected</xsl:attribute></xsl:if>
					その他
				</a>
			</div>
			<div class="clearboth"></div>
		</xsl:for-each>
		
		<!-- カテゴリ指定が無い場合は、全てが選択されたものとしてメニューを表示する。 -->
		<xsl:if test="not(group[@key='category'])">
			<div class="categorymenu">
				<a href="reviewlist.php" class="selected">
					全て
				</a>
				<a href="reviewcatlist.php?category=book">
					本
				</a>
				<a href="reviewcatlist.php?category=cdvideo">
					CD・Video
				</a>
				<a href="reviewcatlist.php?category=other">
					その他
				</a>
			</div>
			<div class="clearboth"></div>
		
		</xsl:if>
		

		<!-- ナビゲーション（上） -->
		<xsl:for-each select="navi">
		
			<div class="pagenavigation">
			
				<xsl:for-each select="prev"><a href="{@href}">&lt;&lt;</a></xsl:for-each>
				<xsl:if test="not(prev)">&lt;&lt;</xsl:if>
				
				&#160;<xsl:value-of select="@position" />ページ&#160;
				
				<xsl:for-each select="next">
					<a href="{@href}">&gt;&gt;</a>
				</xsl:for-each>
				<xsl:if test="not(next)">&gt;&gt;</xsl:if>
				
			</div>
			
		</xsl:for-each>
		
		<div class="reviewlist">
		
		<!-- ここから1件分 -->
		<xsl:for-each select="entry">
		
						<div class="review">
						
								<!-- 画像があれば表示。無ければNO IMAGEを表示。 -->
								<xsl:if test="photo/text()">
									<img src="{photo}&amp;w=100" class="reviewphoto"/>
								</xsl:if>
								<xsl:if test="not(photo/text())">
									<img src="starter.resources/photo_noimage.gif" alt="no image" class="reviewphoto" />
								</xsl:if>
								
								<!-- カテゴリ＆タイトル＆星数（URLがあればタイトルからリンクする） -->
								<div class="title">
									<!-- URL有りの場合（リンク付き） -->
									<xsl:if test="url/text()">
										<a href="{url}">
											[
											<xsl:if test="category='book'">Book</xsl:if>
											<xsl:if test="category='cdvideo'">CD/Video</xsl:if>
											<xsl:if test="category='other'">Other</xsl:if>
											]
											<xsl:value-of select="title" />
										</a>
									</xsl:if>
									
									<!-- URL無しの場合（リンク無し） -->
									<xsl:if test="not(url/text())">
										[
										<xsl:if test="category='book'">Book</xsl:if>
										<xsl:if test="category='cdvideo'">CD/Video</xsl:if>
										<xsl:if test="category='other'">Other</xsl:if>
										]
										<xsl:value-of select="title" />
									</xsl:if>
									
									<!-- 星数 -->
									<span class="stars">
										<xsl:if test="stars='1'">★☆☆☆☆</xsl:if>
										<xsl:if test="stars='2'">★★☆☆☆</xsl:if>
										<xsl:if test="stars='3'">★★★☆☆</xsl:if>
										<xsl:if test="stars='4'">★★★★☆</xsl:if>
										<xsl:if test="stars='5'">★★★★★</xsl:if>
									</span>
								</div>
								
								<!-- 商品説明 -->
								<div class="description">
									<xsl:value-of select="description" disable-output-escaping="yes" />
								</div>
								
								<!--	-->
								<div class="description">
								<strong>■感想・評価</strong><br />
									<xsl:value-of select="substring(review,0,60)" disable-output-escaping="no" /> ...
								</div>
								
								<!-- 更新日時 -->
								<div class="date"><xsl:value-of select="@year" />年<xsl:value-of select="@month" />月<xsl:value-of select="@day" />日&#160;<xsl:value-of select="@hour" />時<xsl:value-of select="@minute" />分&#160;更新</div>
								
								<!-- float解除 -->
								<div class="clearboth"></div>
								
								<!-- 続きへのリンク -->
								<div class="align_right"><a href="review.php{@href}" class="navi_next">詳細</a></div>

							</div>
					
					
		</xsl:for-each>
		
		</div>
		
		<!-- ナビゲーション（下） -->
		<xsl:for-each select="navi">
			<div class="align_right">
			<div class="pagenavigation">
			
				<xsl:for-each select="prev"><a href="{@href}">&lt;&lt;</a></xsl:for-each>
				<xsl:if test="not(prev)">&lt;&lt;</xsl:if>
				
				&#160;<xsl:value-of select="@position" />ページ&#160;
				
				<xsl:for-each select="next">
					<a href="{@href}">&gt;&gt;</a>
				</xsl:for-each>
				<xsl:if test="not(next)">&gt;&gt;</xsl:if>
				
			</div>
			</div>
			
		</xsl:for-each>		
		
	</xsl:template>
</xsl:stylesheet>